gchecky.model.risk_information_t

Package gchecky :: Module model :: Class risk_information_t |
[hide private]
[frames] | no frames]

# Class risk_information_t

source code

    object --+
             |
     gxml.Node --+
                 |
                risk_information_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| avs_response = `String:PATH(avs-response):REQ:EMPTY:VALS("Y","P`...``
| billing_address = `Node:PATH(billing-address):REQ:{ billing_add`...``
| buyer_account_age = `Integer:PATH(buyer-account-age):REQ`
| cvn_response = `String:PATH(cvn-response):REQ:EMPTY:VALS("M","N`...``
| eligible_for_protection = `gxml.Boolean('eligible-for-protection')`
| ip_address = `IP:PATH(ip-address):REQ:EMPTY`
| partial_cc_number = `String:PATH(partial-cc-number):REQ:EMPTY`
| _fields = ``{``'``avs_response``'``:` String:PATH(avs-response):REQ:EMPTY`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### avs_response Value:
      String:PATH(avs-response):REQ:EMPTY:VALS("Y","P","A","N","U")

  ### billing_address Value:
      Node:PATH(billing-address):REQ:{ billing_address_t }

  ### cvn_response Value:
      String:PATH(cvn-response):REQ:EMPTY:VALS("M","N","U","E")

  ### _fields list of meta-Fields of this class. Value:
      {'avs_response': String:PATH(avs-response):REQ:EMPTY:VALS("Y","P","A",
      "N","U"),
       'billing_address': Node:PATH(billing-address):REQ:{ billing_address_t
       },
       'buyer_account_age': Integer:PATH(buyer-account-age):REQ,
       'cvn_response': String:PATH(cvn-response):REQ:EMPTY:VALS("M","N","U",
      "E"),
       'eligible_for_protection': ??,
      ...